-- FEEL FREE TO MODIFY THE BELOW BINDINGS AS DESIRED
-- All keys must be surrounded by quotes "".
-- Examples: "F1" is the 'F1' key on your keyboard.
-- To combine keys, you add dashes like: "ALT-F" or "CTRL-SHIFT-F5"
-- To use mouse buttons instead of keys: "BUTTON2" (for right-click) or "BUTTON5" (for your fifth mouse button)
-- To use keys on the Num Pad, add "NUMPAD" in front of the key. For example, "NUMPAD4" or "NUMPADPLUS".
-- If you want to use a button that isn't listed above as an example, go into WoW's key binding options and see what it looks like there.
-- Then remove the spaces and capitialize everything, and it should be in the correct format.

local BPB_Binds = {
	"1", -- Key for Attack #1
	"2", -- Key for Attack #2
	"3", -- Key for Attack #3
	"4", -- Key for Swap Pet Menu
	"5", -- Key for Throwing Traps
	"F", -- Key for forfeiting
	"R", -- Key for passing your turn
	"F1", -- Key for swapping to Pet #1
	"F2", -- Key for swapping to Pet #2
	"F3", -- Key for swapping to Pet #3
}

------------------------------
-- Addon code starts below  --
------------------------------

-- localize functions
local SOBC = _G.SetOverrideBindingClick

-- use boolean variable to account for Blizzard event misfire bug
local BPB_BindState = false

-- create event handling frame
local BattlePetBinds = CreateFrame("FRAME", "BattlePetBinds")

-- register events
BattlePetBinds:RegisterEvent("ADDON_LOADED")
BattlePetBinds:RegisterEvent("PET_BATTLE_OPENING_START")
BattlePetBinds:RegisterEvent("PET_BATTLE_OPENING_DONE")
BattlePetBinds:RegisterEvent("PET_BATTLE_OVER")
BattlePetBinds:RegisterEvent("PET_BATTLE_CLOSE")

-- event handler function
local function BattlePetBinds_OnEvent(self, event, ...)

	-- if this addon loads then
	if (event == "ADDON_LOADED") and (... == "Battle Pet Binds") then
		
		--[[-- create SavedVariables table using default values if not already found
		if not BPB_Binds then
			BPB_SetDefaults()
		end]]--
		
		-- create and bind hotkeys if we're not in combat and we're in a pet battle
		if not InCombatLockdown() and C_PetBattles.IsInBattle() then
			
			-- create hotkey frames and hotkey text frames (because we know they don't exist at addon load)
			BPB_CreateHotKeys()
			BPB_CreateHotKeyTexts()
			
			-- set up our override binding clicks
			for i = 1, 10 do
				local button = "BPB_HotKey"..i
				SOBC(BattlePetBinds, true, BPB_Binds[i], button)
			end
			
			-- tell the boolean we have set our bindings
			BPB_BindState = true
		end
	
	-- if we start a pet battle and are not in combat then (checking both opening events to account for Blizzard event misfire bug)
	elseif ((event == "PET_BATTLE_OPENING_START") or (event == "PET_BATTLE_OPENING_DONE")) and not InCombatLockdown() then
		
		-- create hotkey frames if they don't exist
		if not BPB_HotKey1 then
			BPB_CreateHotKeys()
		end
		
		-- create hotkey text frames if they don't exist
		if not BPB_HotKeyText1 then
			BPB_CreateHotKeyTexts()
		end
		
		-- if our boolean shows we haven't set binds then
		if (BPB_BindState == false) then
		
			-- set up our override binding clicks
			for i = 1, 10 do
				local button = "BPB_HotKey"..i
				SOBC(BattlePetBinds, true, BPB_Binds[i], button)
			end
			
			-- tell the boolean we have set our bindings
			BPB_BindState = true
		end
	
	-- if the pet battle ends then (checking both closing events to account for Blizzard event misfire bug)
	elseif (event == "PET_BATTLE_OVER") or (event == "PET_BATTLE_CLOSE") then
	
		-- if our boolean shows we have set binds then
		if (BPB_BindState == true) then
		
			-- remove our bindings
			ClearOverrideBindings(BattlePetBinds)
			
			-- tell the boolean that we have removed our bindings
			BPB_BindState = false
		end
	end
end

-- update standard actionbutton 1-5 text indicators
local function BPB_Hook_UpdateHotKey(self)
	
	-- get # of button
	local buttonID = self:GetID()
	
	-- update hotkey text to our new bindings and show it
	self.HotKey:SetText(BPB_Binds[buttonID])
	self.HotKey:Show()
end

-- set up buttons to be clicked on by our new bindings (replaces Bindings.xml)
function BPB_CreateHotKeys()
	
	-- create buttons to be clicked and define them as macros
	for i = 1, 10 do
		local button = "BPB_HotKey"..i
		CreateFrame("Button", button, nil, "SecureActionButtonTemplate")
		_G[button]:SetAttribute("type", "macro")
	end
	
	-- add macro code (to store code for later) into the buttons
	_G["BPB_HotKey1"]:SetAttribute("macrotext", "/run StaticPopup_Hide(\34PET_BATTLE_FORFEIT\34,nil) C_PetBattles.UseAbility(1)")
	_G["BPB_HotKey2"]:SetAttribute("macrotext", "/run StaticPopup_Hide(\34PET_BATTLE_FORFEIT\34,nil) C_PetBattles.UseAbility(2)")
	_G["BPB_HotKey3"]:SetAttribute("macrotext", "/run StaticPopup_Hide(\34PET_BATTLE_FORFEIT\34,nil) C_PetBattles.UseAbility(3)")
	_G["BPB_HotKey4"]:SetAttribute("macrotext", "/run PetBattleFrame.BottomFrame.SwitchPetButton:Click()")
	_G["BPB_HotKey5"]:SetAttribute("macrotext", "/run do local usable = C_PetBattles.IsTrapAvailable() if (usable) then StaticPopup_Hide(\34PET_BATTLE_FORFEIT\34,nil) C_PetBattles.UseTrap() end end")
	_G["BPB_HotKey6"]:SetAttribute("macrotext", "/run StaticPopup_Hide(\34PET_BATTLE_FORFEIT\34,nil) C_PetBattles.ForfeitGame()")
	_G["BPB_HotKey7"]:SetAttribute("macrotext", "/run StaticPopup_Hide(\34PET_BATTLE_FORFEIT\34,nil) C_PetBattles.SkipTurn()")
	_G["BPB_HotKey8"]:SetAttribute("macrotext", "/run if (C_PetBattles.CanPetSwapIn(1)) then C_PetBattles.ChangePet(1) PetBattlePetSelectionFrame_Hide(PetBattleFrame.BottomFrame.PetSelectionFrame) end")
	_G["BPB_HotKey9"]:SetAttribute("macrotext", "/run if (C_PetBattles.CanPetSwapIn(2)) then C_PetBattles.ChangePet(2) PetBattlePetSelectionFrame_Hide(PetBattleFrame.BottomFrame.PetSelectionFrame) end")
	_G["BPB_HotKey10"]:SetAttribute("macrotext", "/run if (C_PetBattles.CanPetSwapIn(3)) then C_PetBattles.ChangePet(3) PetBattlePetSelectionFrame_Hide(PetBattleFrame.BottomFrame.PetSelectionFrame) end")
end

-- set up text indicators for forfeit, pass turn, and pet swapping HotKeys
function BPB_CreateHotKeyTexts()
	
	-- create the fontstrings
	for i = 6, 10 do
		BattlePetBinds:CreateFontString("BPB_HotKeyText"..i, "OVERLAY", "NumberFontNormalSmallGray")
	end
	
	-- set the true parent frame for each fontstring
	_G["BPB_HotKeyText6"]:SetParent(PetBattleFrame.BottomFrame.ForfeitButton)
	_G["BPB_HotKeyText7"]:SetParent(PetBattleFrame.BottomFrame.TurnTimer.SkipButton)
	_G["BPB_HotKeyText8"]:SetParent(PetBattleFrame.BottomFrame.PetSelectionFrame.Pet1)
	_G["BPB_HotKeyText9"]:SetParent(PetBattleFrame.BottomFrame.PetSelectionFrame.Pet2)
	_G["BPB_HotKeyText10"]:SetParent(PetBattleFrame.BottomFrame.PetSelectionFrame.Pet3)
	
	-- set the anchor point for each fontstring
	_G["BPB_HotKeyText6"]:SetPoint("TOPRIGHT", PetBattleFrame.BottomFrame.ForfeitButton, "TOPRIGHT", -1, -3)
	_G["BPB_HotKeyText7"]:SetPoint("TOPRIGHT", PetBattleFrame.BottomFrame.TurnTimer.SkipButton, "TOPRIGHT", -1, -6)
	_G["BPB_HotKeyText8"]:SetPoint("BOTTOMRIGHT", PetBattleFrame.BottomFrame.PetSelectionFrame.Pet1, "BOTTOMRIGHT", -6, 6)
	_G["BPB_HotKeyText9"]:SetPoint("BOTTOMRIGHT", PetBattleFrame.BottomFrame.PetSelectionFrame.Pet2, "BOTTOMRIGHT", -6, 6)
	_G["BPB_HotKeyText10"]:SetPoint("BOTTOMRIGHT", PetBattleFrame.BottomFrame.PetSelectionFrame.Pet3, "BOTTOMRIGHT", -6, 6)
	
	-- set the properties of the new fontstrings (justification, height, width, text and isvisible)
	for i = 6, 10 do
		local fstr = "BPB_HotKeyText"..i
		_G[fstr]:SetJustifyH("RIGHT")
		_G[fstr]:SetHeight(10)
		_G[fstr]:SetWidth(36)
		_G[fstr]:SetText(BPB_Binds[i])
		_G[fstr]:Show()
	end
end

-- set our event handler function
BattlePetBinds:SetScript("OnEvent", BattlePetBinds_OnEvent)

-- hook script
hooksecurefunc("PetBattleAbilityButton_UpdateHotKey", BPB_Hook_UpdateHotKey)